@@ -108,7 +108,7 @@ ImageViewer::ImageViewer()
 {
     readSettings(false);
 
-    float gam = Strutil::stof(Sysutil::getenv("GAMMA"));
+    float gam = Strutil::stof(Sysutil::getenv("GAMMA", "2.2"));
     if (gam >= 0.1 && gam <= 5)
         m_default_gamma = gam;
     // FIXME -- would be nice to have a more nuanced approach to display
